@@ -22,6 +22,7 @@ import requests  # type: ignore
 from .config import (
     EXTRACT_PIPELINES,
     LIST_JOBS_ORDER_BY,
+    SOURCE_LANG,
     SOURCE_OBJECT_MAPPING,
     SUMMARY_LENGTHS_RANGE,
     SUMMARY_PIPELINES,
@@ -46,6 +47,7 @@ from .core_objects import (
 from .login import get_token
 from .utils import (
     _check_extract_pipelines,
+    _check_source_lang,
     _check_summary_length,
     _check_summary_pipelines,
     _format_lengths,
@@ -244,8 +246,9 @@ class Client:
         ephemeral_data: Optional[bool] = False,
         only_api: Optional[bool] = True,
         pipelines: Union[str, List[str]] = ["transcribe", "summarize"],  # noqa: B006
+        source_lang: Optional[str] = None,
         split_long_utterances: Optional[bool] = False,
-        summary_length: Union[int, List[int]] = 3,
+        summary_length: Optional[Union[int, List[int]]] = None,
         tags: Optional[Union[str, List[str]]] = None,
     ) -> SummarizeJob:
         """Start a Summary job."""
@@ -254,20 +257,27 @@ class Client:
                 f"Invalid summary type. Available types are: {', '.join(SUMMARY_TYPES)}"
             )
 
-        if _check_summary_length(summary_length) is False:
-            raise ValueError(
-                f"""
-                You must specify a valid summary length. Summary length must be an integer or a list of integers.
-                The integer values must be between {SUMMARY_LENGTHS_RANGE[0]} and {SUMMARY_LENGTHS_RANGE[1]}.
-            """
-            )
-        if summary_type == "reason_conclusion" and summary_length:
-            logger.warning(
+        if summary_type == "reason_conclusion":
+            if summary_length:
+                logger.warning(
+                    """
+                    You have specified a summary length for a reason_conclusion summary but reason_conclusion summaries
+                    do not use a summary length. The summary_length parameter will be ignored.
                 """
-                You have specified a summary length for a reason_conclusion summary but reason_conclusion summaries
-                do not use a summary length. The summary_length parameter will be ignored.
-            """
-            )
+                )
+        else:
+            if summary_length is None:
+                logger.warning(
+                    "You have not specified a summary length. Defaulting to 3."
+                )
+                summary_length = 3
+            if _check_summary_length(summary_length) is False:
+                raise ValueError(
+                    f"""
+                    You must specify a valid summary length. Summary length must be an integer or a list of integers.
+                    The integer values must be between {SUMMARY_LENGTHS_RANGE[0]} and {SUMMARY_LENGTHS_RANGE[1]}.
+                """
+                )
 
         if _check_summary_pipelines(pipelines) is False:
             raise ValueError(
@@ -284,6 +294,23 @@ class Client:
             """
             )
 
+        if source_lang is None:
+            source_lang = "en"
+        if _check_source_lang(source_lang) is False:
+            raise ValueError(
+                f"""
+                You must specify a valid source language. Available languages are: {", ".join(SOURCE_LANG)}.
+            """
+            )
+        elif source_lang != "en":
+            logger.warning(
+                f"""
+                You have specified {source_lang} as the source language. This is currently in beta and may not
+                be as accurate as the English model. We are working to improve the accuracy of the non-English
+                models. If you have any feedback, please contact us at info@wordcab.com.
+            """
+            )
+
         source = source_object.source
         if source not in SOURCE_OBJECT_MAPPING.keys():
             raise ValueError(
@@ -315,10 +342,12 @@ class Client:
             "ephemeral_data": str(ephemeral_data).lower(),
             "only_api": str(only_api).lower(),
             "pipeline": pipelines,
+            "source_lang": source_lang,
             "split_long_utterances": str(split_long_utterances).lower(),
             "summary_type": summary_type,
-            "summary_lens": _format_lengths(summary_length),
         }
+        if summary_type != "reason_conclusion" and summary_length:
+            params["summary_lens"] = _format_lengths(summary_length)
         if tags:
             params["tags"] = _format_tags(tags)
 
@@ -390,7 +419,7 @@ class Client:
                     list_jobs.append(ExtractJob(**job))
             return ListJobs(
                 page_count=int(data["page_count"]),
-                next_page=data["next"],
+                next_page=data.get("next"),
                 results=list_jobs,
             )
         else:
@@ -448,7 +477,7 @@ class Client:
             data = r.json()
             return ListTranscripts(
                 page_count=int(data["page_count"]),
-                next_page=data["next"],
+                next_page=data.get("next"),
                 results=[
                     BaseTranscript(**transcript) for transcript in data["results"]
                 ],
@@ -514,7 +543,7 @@ class Client:
             data = r.json()
             return ListSummaries(
                 page_count=int(data["page_count"]),
-                next_page=data["next"],
+                next_page=data.get("next"),
                 results=[BaseSummary(**summary) for summary in data["results"]],
             )
         else:
